@@ -62,7 +62,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.47.10.1'; # our $VERSION = '';
+$VERSION = '0.47.11'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -1042,7 +1042,16 @@ sub opt
 
 	require $configfile;
 	#if ( not ( $outfile ) ) { $outfile = "$mypath/$file-$fileconfig-feedback.txt"; } 
-	if ( not ( $tofile ) ) { $tofile = "$mypath/$file-tofile.txt"; } 
+	if ( not ( $tofile ) ) { 
+		unless ( $dowhat{system} eq "windows" )
+		{
+			$tofile = "$mypath/$file-tofile.txt"; 
+		}
+		else
+		{
+			$tofile = "$mypath\\$file-tofile.txt"; 
+		}
+	} 
 	
 	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 
@@ -1075,9 +1084,9 @@ sub opt
 	{
 		if ( ( @sweepseed ) and ( @chancedata ) ) # IF THIS VALUE IS DEFINED. TO BE FIXED. ZZZ
 		{
-			my $yield = fromsweep_toopt( @sweeps ); say $tee "Dumper(\$yield): " . Dumper($yield);
-			@caseseed = @{ $yield[0] }; say $tee "Dumper(\@caseseed): " . Dumper(@caseseed);
-			@chanceseed = @{ $yield[1] }; say $tee "Dumper(\@chanceseed): " . Dumper(@chanceseed);
+			my $yield = fromsweep_toopt( @sweeps ); #say $tee "Dumper(\$yield): " . Dumper($yield);
+			@caseseed = @{ $yield[0] }; #say $tee "Dumper(\@caseseed): " . Dumper(@caseseed);
+			@chanceseed = @{ $yield[1] }; #say $tee "Dumper(\@chanceseed): " . Dumper(@chanceseed);
 		}
 	}
 			
@@ -1113,7 +1122,7 @@ sub opt
 		#say "dump(\@varinumbers), " . dump(@varinumbers); #say "dumpBEFORE(\@miditers), " . dump(@miditers);
 	
 		calcoverlaps( @sweeps ); # PRODUCES @calcoverlaps WHICH IS global. ZZZ
-		say $tee "VARINUMBERS: " . dump ( @varinumbers );
+		#say $tee "VARINUMBERS: " . dump ( @varinumbers );
 		@mediumiters = calcmediumiters( @varinumbers ); say $tee "(\@mediumitems): " . dump(@mediumiters); # globsALS. ZZZ
 		#$itersnum = getitersnum($countcase, $varinumber, @varinumbers); #say "\$itersnum OUT = $itersnum";
 		
