@@ -39,7 +39,7 @@ use warnings::unused;
 
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.43.0'; # our $VERSION = '';
+$VERSION = '0.43.11'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -228,7 +228,10 @@ sub descend
 					{
 						print  SELECTEDMIXED ",";
 					}
-					else {print  SELECTEDMIXED "\n";}
+					else 
+					{
+						print  SELECTEDMIXED "\n";
+					}
 					$countin++;
 				}
 				$countout++;
@@ -494,7 +497,16 @@ sub descend
 		my $winnerval = $winnerelms[$#winnerelms];
 		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); say TOFILE "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
 		
-		my $message = "$mypath/attention.txt";
+		my $message;
+		unless ( $dowhat{system} eq "windows" ) 
+		{
+			$message = "$mypath/attention.txt";
+		}
+		else
+		{
+			$message = "$mypath\\attention.txt";
+		}
+		
 		open( MESSAGE, ">>$message");
 		my $countelm = 0;
 		foreach my $elm (@lines)
