@@ -36,7 +36,7 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.47'; # our $VERSION = '';
+$VERSION = '0.47.11'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -694,7 +694,15 @@ sub report # This function retrieves the results of interest from the texts file
 		open( REPLIST, ">>$replist" ) or die( "$!" ); say TOFILE "dump---(\$replist): " . dump($replist) . "\n\n";  
 		open( REPBLOCK, ">>$repblock" ) or die( "$!" ); say TOFILE "dump---(\$repblock): " . dump($repblock) . "\n\n";
 		
-		$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
+		unless ( $dowhat{system} eq "windows" ) 
+		{
+			$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
+		}
+		else
+		{
+			$repfile = "$mypath\\$file-report-$countcase-$countblock.txt";  say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
+		}
+		
 		open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
 		
 		push ( @{ $repstruct[$countcase][$countblock] }, $repfile );
@@ -939,7 +947,8 @@ sub get_files # UNUSED. LEGACY. CUT.
 								if ( $elt_of_row eq $columns_to_report[0] )
 								{
 									$title_of_column = "$elt_of_row";
-								} else
+								} 
+								else
 								{
 									$title_of_column =
 									  "$elt_of_row-" . "$file_and_period";
