@@ -42,7 +42,7 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.47'; # our $VERSION = '';
+$VERSION = '0.47.11'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -200,6 +200,16 @@ sub sim    # This function launch the simulations in ESP-r
 				
 				if ( $tooltype eq "esp-r" )
 				{	
+					my $launchline;
+					unless ( $dowhat{system} eq "windows" ) 
+					{
+						$launchline = "-file $simelt/cfg/$fileconfig -mode script";
+					}
+					else
+					{
+						$launchline = "-file $simelt\\cfg\\$fileconfig -mode script";
+					}
+					
 					say TOFILE "dump(\%simtitles): " . dump( %simtitles ); 
 					say TOFILE "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
 					say TOFILE "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
@@ -253,7 +263,7 @@ sub sim    # This function launch the simulations in ESP-r
 						
 						push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ][$counttool] }, $resfile );
 						print SIMBLOCK "$resfile\n";
-					
+						
 						if ( ( not ( $resfile ~~ @simcases ) ) and ( not ( -e $resfile ) ) )
 						{
 							push ( @simcases, $resfile );
@@ -265,7 +275,7 @@ sub sim    # This function launch the simulations in ESP-r
 								{
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile and $flfile." ;
 									my $printthis =	
-"bps -file $simelt/cfg/$fileconfig -mode script<<XXX
+"bps $launchline<<XXX
 
 c
 $resfile
@@ -302,7 +312,7 @@ XXX
 								{
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile. " ;
 									my $printthis =
-"bps -file $simelt/cfg/$fileconfig -mode script<<XXX
+"bps $launchline<<XXX
 
 c
 $resfile
@@ -362,12 +372,29 @@ $printthis
 						$tempname =~ s/$mypath\/// ; say TOFILE "dump(\$tempname ): " . dump( $tempname ); 
 						my $epnewfile = $tempname . $epnewfragment . "$modfiletype"; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
 						my $epresroot = $tempname . $epnewfragment ; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
-						my $epnewpath = $to . $epdir . "/" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
+						
+						my $epnewpath;
+						unless ( $dowhat{system} eq "windows" ) 
+						{ 
+							$epnewpath = $to . $epdir . "/" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
+						}
+						else
+						{ 
+							$epnewpath = $to . $epdir . "\\" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
+						}
+						
 						my @simdos = @{ $simtitle_ref };
 						my @changes = @simdos[ 12..$#simdos ]; say TOFILE "dump(\@changes ): " . dump( @changes ); 
 						if ( $tooltype eq "energyplus" ) # RESTORES DEFAULTS FOR ENERGYPLUS
 						{
-							$outputdir = "/Output";
+							unless ( $dowhat{system} eq "windows" ) 
+							{
+								$outputdir = "/Output";
+							}
+							else
+							{
+								$outputdir = "\\Output";
+							}
 							$modfiletype = ".idf";
 							unless ( defined( $resfilename ) )
 							{
@@ -399,7 +426,16 @@ $printthis
 						my $file_eplus = "$to/$file_eplus";  #say TOFILE "dump(\$file_eplus ): " . dump( $file_eplus ); 
 						
 						my $simelt = $mypath . "$outputdir"; #say TOFILE "dump(\$simelt ): " . dump( $simelt ); 
-						my $resfile = "$simelt/$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
+						
+						my $resfile;
+						unless ( $dowhat{system} eq "windows" ) 
+						{
+							$resfile = "$simelt/$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
+						}
+						else
+						{
+							$resfile = "$simelt\\$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
+						}
 						
 						if (not (-e $simblock ) )
 						{
@@ -462,14 +498,31 @@ $printthis
 								{
 									unless ( $exeonfiles eq "n" )
 										{
-										my $tempf = $epnewpath; #say TOFILE "dump(\$tempf1 ): " . dump( $tempf ); 
-										$tempf =~ s/$to$epdir\///;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
-										$templaunch = $mypath . "/" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
-										`cp -f $epnewpath $templaunch`;
+										
+										my $tempf = $epnewpath; #say TOFILE "dump(\$tempf1 ): " . dump( $tempf );
+										unless ( $dowhat{system} eq "windows" ) 
+										{
+											$tempf =~ s/$to$epdir\///;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
+											$templaunch = $mypath . "/" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
+											`cp -f $epnewpath $templaunch`;
+										}
+										else
+										{
+											$tempf =~ s/$to$epdir\\//;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
+											$templaunch = $mypath . "\\" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
+											`xcopy  /e /c /r /y $epnewpath $templaunch`;
+										}
 										`runenergyplus $templaunch $epwfile`;
 										#`rm -f $templaunch`;
 									}
-									print TOFILE "cp -f $epnewpath $templaunch\n";
+									unless ( $dowhat{system} eq "windows" ) 
+									{
+										print TOFILE "cp -f $epnewpath $templaunch\n";
+									}
+									else
+									{
+										print TOFILE "xcopy  /e /c /r /y $epnewpath $templaunch\n";
+									}
 									print TOFILE "runenergyplus $templaunch $epwfile\n";
 									#print TOFILE "rm -f $templaunch\n";
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: using $epnewpath (actually $templaunch) to obtain $resfile. " ;										
